@@ -1,7 +1,7 @@
 package Bencher::Formatter::Sort;
 
-our $DATE = '2016-10-27'; # DATE
-our $VERSION = '1.029'; # VERSION
+our $DATE = '2016-10-28'; # DATE
+our $VERSION = '1.030'; # VERSION
 
 use 5.010001;
 use strict;
@@ -23,7 +23,7 @@ sub munge_result {
         for my $by0 (@{ $self->{by} }) {
             my ($desc, $by) = $by0 =~ /^(-?)(.+)/;
             return 0 unless defined($a->{$by}) && defined($b->{$by});
-            my $numeric = $by =~ /time|time|errors|samples/ ? 1:0; # XXX ad-hoc
+            my $numeric = $by =~ /time|errors|samples/ ? 1:0; # XXX ad-hoc
             my $res = ($desc ? -1:1) * ($numeric ?
                                             $a->{$by} <=> $b->{$by} :
                                             $a->{$by} cmp $b->{$by});
@@ -48,7 +48,7 @@ Bencher::Formatter::Sort - Sort rows
 
 =head1 VERSION
 
-This document describes version 1.029 of Bencher::Formatter::Sort (from Perl distribution Bencher-Backend), released on 2016-10-27.
+This document describes version 1.030 of Bencher::Formatter::Sort (from Perl distribution Bencher-Backend), released on 2016-10-28.
 
 =head1 DESCRIPTION
 
